@@ -2,6 +2,7 @@ from .database import DatabaseProvider
 from .elasticsearch import ElasticSearchProvider
 from .redis_provider import RedisProvider
 from .ssl_provider import SSLProvider
+from .base import BaseProvider
 
 DEFAULT_PROVIDERS = {
     'database': DatabaseProvider,
@@ -11,6 +12,7 @@ DEFAULT_PROVIDERS = {
 }
 
 __all__ = [
+    'BaseProvider',
     'DatabaseProvider',
     'RedisProvider',
     'ElasticSearchProvider',
